@@ -140,13 +140,13 @@ namespace sfc {
   //
   //   R_xlen_t i, j;
   //
-  //   for( i = 0; i < n_polygons; i++ ) {
+  //   for( i = 0; i < n_polygons; ++i ) {
   //     Rcpp::List sfgs = lst[i];
   //     R_xlen_t n_linestrings = sfgs.size();
   //
   //     Rcpp::List ml( n_linestrings );
   //
-  //     for( j = 0; j < n_linestrings; j++ ) {
+  //     for( j = 0; j < n_linestrings; ++j ) {
   //
   //       SEXP this_linestring = sfgs[j];
   //
@@ -473,70 +473,6 @@ namespace sfc {
     return Rcpp::List::create();
   }
 
-  // Must have both polygon_id and linestring_id
-  // so the functions can be overloaded properly
-  // otherwise there will be ambiguous functions
-  // inline SEXP sfc_polygon(
-  //     SEXP& x,
-  //     SEXP& geometry_cols,
-  //     SEXP& polygon_id
-  // ) {
-  //
-  // }
-
-  // is the idea here to first get the vector of polygon_ids
-  // but keep the line_ids as a column reference
-  // then subset the df in teh outerloop by polygon_id
-  // then go in and get the sfg_polygon based on the line_ids?
-  inline SEXP sfc_polygon(
-    Rcpp::DataFrame& df,
-    Rcpp::IntegerVector& geometry_cols,
-    int& linestring_id,
-    Rcpp::IntegerMatrix& polygon_positions,
-    bool close = true
-  ) {
-
-    Rcpp::NumericVector bbox = sfheaders::bbox::start_bbox();
-    Rcpp::NumericVector z_range = sfheaders::zm::start_z_range();
-    Rcpp::NumericVector m_range = sfheaders::zm::start_m_range();
-
-    sfheaders::bbox::calculate_bbox( bbox, df, geometry_cols );
-
-    R_xlen_t n_col = df.ncol();
-    sfheaders::zm::calculate_zm_ranges( n_col, z_range, m_range, df, geometry_cols );
-
-
-    R_xlen_t n_polygons = polygon_positions.nrow();
-    R_xlen_t i;
-    Rcpp::List sfc( n_polygons );
-
-    int start;
-    int end;
-    Rcpp::StringVector df_names = df.names();
-
-    for( i = 0; i < n_polygons; i++ ) {
-      start = polygon_positions( i, 0 );
-      end = polygon_positions( i, 1 );
-      Rcpp::DataFrame df_subset = sfheaders::utils::subset_dataframe( df, df_names, start, end );
-      sfc( i ) = sfheaders::sfg::sfg_polygon( df_subset, geometry_cols, linestring_id, close );
-    }
-
-    sfheaders::sfc::make_sfc( sfc, sfheaders::sfc::SFC_POLYGON, bbox, z_range, m_range );
-    return sfc;
-  }
-
-
-  inline SEXP sfc_polygon(
-      Rcpp::DataFrame& df,
-      Rcpp::IntegerVector& geometry_cols,
-      SEXP& polygon_ids,
-      int& linestring_id,
-      bool close = true
-  ) {
-    Rcpp::IntegerMatrix polygon_positions = sfheaders::utils::id_positions( polygon_ids );
-    return sfc_polygon( df, geometry_cols, linestring_id, polygon_positions, close );
-  }
-
   inline SEXP sfc_polygon(
     Rcpp::DataFrame& df,
     Rcpp::StringVector& geometry_cols,
@@ -553,7 +489,6 @@ namespace sfc {
     R_xlen_t n_col = df.ncol();
     sfheaders::zm::calculate_zm_ranges( n_col, z_range, m_range, df, geometry_cols );
 
-
     R_xlen_t n_polygons = polygon_positions.nrow();
 
     R_xlen_t i;
@@ -561,12 +496,16 @@ namespace sfc {
 
     int start;
     int end;
-    Rcpp::StringVector df_names = df.names();
 
-    for( i = 0; i < n_polygons; i++ ) {
+    // issue 56 - no need to keep all the columns in the subset_dataframe
+    Rcpp::StringVector keep_columns = sfheaders::utils::concatenate_vectors( geometry_cols, linestring_id );
+    Rcpp::DataFrame df_keep = df[ keep_columns ];
+    Rcpp::StringVector df_names = df_keep.names();
+
+    for( i = 0; i < n_polygons; ++i ) {
       start = polygon_positions( i, 0 );
       end = polygon_positions( i, 1 );
-      Rcpp::DataFrame df_subset = sfheaders::utils::subset_dataframe( df, df_names, start, end );
+      Rcpp::DataFrame df_subset = sfheaders::utils::subset_dataframe( df_keep, df_names, start, end );
       sfc( i ) = sfheaders::sfg::sfg_polygon( df_subset, geometry_cols, linestring_id, close );
     }
 
@@ -574,6 +513,33 @@ namespace sfc {
     return sfc;
   }
 
+  inline SEXP sfc_polygon(
+      Rcpp::DataFrame& df,
+      Rcpp::IntegerVector& geometry_cols,
+      int& linestring_id,
+      Rcpp::IntegerMatrix& polygon_positions,
+      bool close = true
+  ) {
+
+    Rcpp::StringVector df_names = df.names();
+    Rcpp::StringVector str_geometry_cols = df_names[ geometry_cols ];
+    Rcpp::String str_linestring_id = df_names[ linestring_id ];
+    return sfc_polygon( df, str_geometry_cols, str_linestring_id, polygon_positions, close );
+
+  }
+
+  inline SEXP sfc_polygon(
+      Rcpp::DataFrame& df,
+      Rcpp::IntegerVector& geometry_cols,
+      SEXP& polygon_ids,
+      int& linestring_id,
+      bool close = true
+  ) {
+    Rcpp::IntegerMatrix polygon_positions = sfheaders::utils::id_positions( polygon_ids );
+    return sfc_polygon( df, geometry_cols, linestring_id, polygon_positions, close );
+  }
+
+
   inline SEXP sfc_polygon(
       Rcpp::DataFrame& df,
       Rcpp::StringVector& geometry_cols,
@@ -601,7 +567,6 @@ namespace sfc {
     R_xlen_t n_col = im.ncol();
     sfheaders::zm::calculate_zm_ranges( n_col, z_range, m_range, im, geometry_cols );
 
-
     R_xlen_t n_polygons = polygon_positions.nrow();
     R_xlen_t i;
     Rcpp::List sfc( n_polygons );
@@ -609,7 +574,7 @@ namespace sfc {
     int start;
     int end;
 
-    for( i = 0; i < n_polygons; i++ ) {
+    for( i = 0; i < n_polygons; ++i ) {
       start = polygon_positions( i, 0 );
       end = polygon_positions( i, 1 );
       Rcpp::IntegerMatrix im2 = im( Rcpp::Range(start, end), Rcpp::_ );
@@ -655,7 +620,7 @@ namespace sfc {
     int start;
     int end;
 
-    for( i = 0; i < n_polygons; i++ ) {
+    for( i = 0; i < n_polygons; ++i ) {
       start = polygon_positions( i, 0 );
       end = polygon_positions( i, 1 );
       Rcpp::NumericMatrix nm2 = nm( Rcpp::Range(start, end), Rcpp::_ );
@@ -968,7 +933,6 @@ namespace sfc {
     Rcpp::stop("sfheaders - polygon case not yet implemented");   // #nocov
     return Rcpp::List::create(); // ??
   }
-
 } // sfc
 } // sfheaders
 
